==> webkit2gtk_2.48.3.orig.tar.xz: webkitgtk-2.48.3/Source/WebCore/platform/graphics/filters/FilterEffectApplier.h <==
/*
 * Copyright (C) 2021 Apple Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "FilterImageVector.h"
#include <wtf/CheckedRef.h>

namespace WebCore {

class Filter;

class FilterEffectApplier {
public:
    template<typename FilterEffectApplierType, typename FilterEffectType>
    static std::unique_ptr<FilterEffectApplierType> create(const FilterEffectType& effect)
    {
        return makeUnique<FilterEffectApplierType>(effect);
    }
    
    FilterEffectApplier() = default;
    virtual ~FilterEffectApplier() = default;
    
    virtual bool apply(const Filter&, const FilterImageVector& inputs, FilterImage& result) const = 0;
};

template<typename FilterEffectType>
class FilterEffectConcreteApplier : public FilterEffectApplier {
public:
    FilterEffectConcreteApplier(const FilterEffectType& effect)
        : m_effect(effect)
    {
    }
    
protected:
    const CheckedRef<const FilterEffectType> m_effect;
};

} // namespace WebCore

==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/WebCore/platform/graphics/filters/FilterEffectApplier.h <==
/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/FilterImageVector.h>
#include <wtf/CheckedRef.h>

namespace WebCore {

class Filter;

class FilterEffectApplier {
public:
    template<typename FilterEffectApplierType, typename FilterEffectType>
    static std::unique_ptr<FilterEffectApplierType> create(const FilterEffectType& effect)
    {
        return makeUnique<FilterEffectApplierType>(effect);
    }
    
    FilterEffectApplier() = default;
    virtual ~FilterEffectApplier() = default;
    
    virtual bool apply(const Filter&, std::span<const Ref<FilterImage>> inputs, FilterImage& result) const = 0;
};

template<typename FilterEffectType>
class FilterEffectConcreteApplier : public FilterEffectApplier {
public:
    FilterEffectConcreteApplier(const FilterEffectType& effect)
        : m_effect(effect)
    {
    }
    
protected:
    const CheckedRef<const FilterEffectType> m_effect;
};

} // namespace WebCore
